package java.security.spec;

import java.math.BigInteger;

public class EllipticCurve
{
    private final ECField field;
    private final BigInteger a;
    private final BigInteger b;
    private final byte[] seed;
    
    private static void checkValidity(ECField ecField, BigInteger val, String str) {
        if ((ecField instanceof ECFieldFp)) {
            if (((ECFieldFp)ecField).getP().compareTo(val) != 1) {
                throw new IllegalArgumentException(str + " is too large");
            }
            if (val.signum() < 0) {
                throw new IllegalArgumentException(str + " is negative");
            }
        }
        else if (ecField instanceof ECFieldF2m && val.bitLength() > ((ECFieldF2m)ecField).getM()) {
            throw new IllegalArgumentException(str + " is too large");
        }
    }
    
    public EllipticCurve(ECField ecField, BigInteger bigInteger, BigInteger bigInteger2) {
        this(ecField, bigInteger, bigInteger2, (byte[])null);
    }
    
    public EllipticCurve(ECField field, BigInteger a, BigInteger b, byte[] array) {
        if (field == null) {
            throw new NullPointerException("field is null");
        }
        if (a == null) {
            throw new NullPointerException("first coefficient is null");
        }
        if (b == null) {
            throw new NullPointerException("second coefficient is null");
        }
        checkValidity(field, a, "first coefficient");
        checkValidity(field, b, "second coefficient");
        this.field = field;
        this.a = a;
        this.b = b;
        if (array != null) {
            this.seed = (byte[])array.clone();
        }
        else {
            this.seed = null;
        }
        return;
    }
    
    public ECField getField() {
        return this.field;
    }
    
    public BigInteger getA() {
        return this.a;
    }
    
    public BigInteger getB() {
        return this.b;
    }
    
    public byte[] getSeed() {
        if (this.seed == null) {
            return null;
        }
        return (byte[])this.seed.clone();
    }
    
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if ((o instanceof EllipticCurve)) {
            EllipticCurve ellipticCurve = (EllipticCurve)o;
            if (this.field.equals(ellipticCurve.field) && this.a.equals(ellipticCurve.a) && this.b.equals(ellipticCurve.b)) {
                return true;
            }
        }
        return false;
    }
    
    @Override
    public int hashCode() {
        return this.field.hashCode() << 6 + (this.a.hashCode() << 4) + (this.b.hashCode() << 2);
    }
}
